@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2009 Dan Pascu. See LICENSE for details.
+# Copyright (C) 2006-2012 Dan Pascu. See LICENSE for details.
 #
 
 """Basic data types to describe the type of the entries in the configuration file"""
@@ -7,39 +7,34 @@
 __all__ = ['Boolean', 'LogLevel', 'StringList', 'IPAddress', 'Hostname', 'HostnameList',
            'NetworkRange', 'NetworkRangeList', 'NetworkAddress', 'EndpointAddress']
 
-import socket
 import re
+import socket
 import struct
 
 from application import log
+from application.python import limit
 
 
 class Boolean(int):
     """A boolean validator that handles multiple boolean input keywords: yes/no, true/false, on/off, 1/0"""
-    __states = {'1': True, 'yes': True, 'true': True, 'on': True, 1: True, True: True,
-                '0': False, 'no': False, 'false': False, 'off': False, 0: False, False: False}
+    __valuemap__ = {'1': True,  'yes': True, 'true': True,   'on': True,
+                    '0': False, 'no': False, 'false': False, 'off': False}
     def __new__(cls, value):
-        try: 
-            value + 0
-        except:
-            try: value + ''
-            except: raise TypeError('value must be a string')
-            else: val = value.lower()
-        else:
-            val = value # eventually we can accept any int value by using 'not not value'
+        if isinstance(value, (int, long, float)):
+            return bool(value)
+        elif not hasattr(value, 'lower'):
+            raise TypeError("value must be a string, number or boolean")
         try:
-            return Boolean.__states[val]
+            return cls.__valuemap__[value.lower()]
         except KeyError:
-            raise ValueError, 'not a boolean: %s' % value
+            raise ValueError('not a boolean value: %r' % value)
 
 
 class LogLevel(int):
     """A log level indicated by a non-negative integer or one of the named attributes of log.level"""
     def __new__(cls, value):
-        def constrain(value, min_value, max_value):
-            return min(max(min_value, value), max_value)
         if isinstance(value, (int, long)):
-            return log.NamedLevel(constrain(value, log.level.ALL, log.level.NONE))
+            return log.NamedLevel(limit(value, min=log.level.ALL, max=log.level.NONE))
         elif not isinstance(value, basestring):
             raise TypeError("value must be a string, int or long")
         log_level = value.upper()
@@ -47,7 +42,7 @@ class LogLevel(int):
         if log_level in names:
             return getattr(log.level, log_level)
         try:
-            return log.NamedLevel(constrain(int(log_level), log.level.ALL, log.level.NONE))
+            return log.NamedLevel(limit(int(log_level), min=log.level.ALL, max=log.level.NONE))
         except ValueError:
             raise ValueError("invalid log level: %s" % value)
 
@@ -148,14 +143,14 @@ class NetworkRange(tuple):
             try:
                 net = socket.gethostbyname(description) # if not a net/mask it may be a host or ip
             except socket.gaierror:
-                raise NameError, "invalid hostname or IP address: '%s'" % description
+                raise NameError("invalid hostname or IP address: '%s'" % description)
             netbits = 32
         if netbits < 0 or netbits > 32:
-            raise ValueError, "invalid network mask in address: '%s' (should be between 0 and 32)" % description
+            raise ValueError("invalid network mask in address: '%s' (should be between 0 and 32)" % description)
         try:
             netaddr = socket.inet_aton(net)
-        except:
-            raise ValueError, "invalid IP address: '%s'" % net
+        except Exception:
+            raise ValueError("invalid IP address: '%s'" % net)
         mask = (0xFFFFFFFFL << 32-netbits) & 0xFFFFFFFFL
         netbase = struct.unpack('!L', netaddr)[0] & mask
         return (netbase, mask)
