@@ -1,39 +1,32 @@
-# Copyright (C) 2009-2011 AG Projects. See LICENSE for details.
+# Copyright (C) 2009-2012 AG Projects. See LICENSE for details.
 #
 
 """Implements a notification system"""
 
-from __future__ import with_statement
-
 __all__ = ['Any', 'UnknownSender', 'IObserver', 'NotificationData', 'Notification', 'NotificationCenter', 'ObserverWeakrefProxy']
 
-
 import weakref
 from collections import deque
+from datetime import datetime
 from threading import Lock
+from time import time
 from zope.interface import Interface, implements
 
 from application import log
 from application.python.descriptor import ThreadLocal
-from application.python.types import Singleton
+from application.python.types import Singleton, MarkerType
+from application.python.weakref import weakobjectmap
 
 
 ## Special objects
 
-class SpecialType(type):
-    def __str__(cls):
-        return cls.__name__
-    __repr__ = __str__
-
 class Any(object):
     """Any sender or notification name"""
-    __metaclass__ = SpecialType
+    __metaclass__ = MarkerType
 
 class UnknownSender(object):
     """A special sender used for anonymous notifications"""
-    __metaclass__ = SpecialType
-
-del SpecialType
+    __metaclass__ = MarkerType
 
 
 ## Notification Observer
@@ -54,7 +47,7 @@ class ObserverWeakrefProxy(object):
 
     implements(IObserver)
 
-    observer_map = weakref.WeakKeyDictionary()
+    observer_map = weakobjectmap()
     lock = Lock()
 
     def __new__(cls, observer):
@@ -90,23 +83,29 @@ class NotificationData(object):
     def __repr__(self):
         return '%s(%s)' % (self.__class__.__name__, ', '.join('%s=%r' % (name, value) for name, value in self.__dict__.iteritems()))
 
-    __str__ = __repr__
 
 class Notification(object):
     """Object representing a notification"""
 
     def __init__(self, name, sender=UnknownSender, data=NotificationData()):
-        if Any in (name, sender):
+        if name is Any or sender is Any:
             raise ValueError("name and/or sender must not be the special object Any")
         self.name = name
         self.sender = sender
         self.data = data
+        self.timestamp = time()
+
+    @property
+    def datetime(self):
+        return self.__dict__.get('datetime') or self.__dict__.setdefault('datetime', datetime.fromtimestamp(self.timestamp))
+
+    @property
+    def utcdatetime(self):
+        return self.__dict__.get('utcdatetime') or self.__dict__.setdefault('utcdatetime', datetime.utcfromtimestamp(self.timestamp))
 
     def __repr__(self):
         return '%s(%r, %r, %r)' % (self.__class__.__name__, self.name, self.sender, self.data)
 
-    __str__ = __repr__
-
 
 ## Notification Center
 
@@ -198,6 +197,7 @@ class NotificationCenter(object):
         """
 
         notification = Notification(name, sender, data)
+        notification.center = self
         queue = self.queue
         queue.append(notification)
         if len(queue) > 1: # This is true if we post a notification from inside a notification handler
@@ -214,7 +214,7 @@ class NotificationCenter(object):
             for observer in observers:
                 try:
                     observer.handle_notification(notification)
-                except:
+                except Exception:
                     log.error("Exception occured in observer %r while handling notification %r" % (observer, notification.name))
                     log.err()
             queue.popleft()
