@@ -1,13 +1,16 @@
-# Copyright (C) 2007-2011 Dan Pascu. See LICENSE for details.
+# Copyright (C) 2007-2012 Dan Pascu. See LICENSE for details.
 #
 
 """Decorators and helper functions for writing well behaved decorators."""
 
-from __future__ import with_statement
-
-
 __all__ = ['decorator', 'preserve_signature', 'execute_once']
 
+from inspect import getargspec, formatargspec
+from itertools import count
+from threading import RLock
+
+from application.python.weakref import weakobjectmap
+
 
 def decorator(func):
     """A syntactic marker with no other effect than improving readability."""
@@ -16,8 +19,6 @@ def decorator(func):
 
 def preserve_signature(func):
     """Preserve the original function signature and attributes in decorator wrappers."""
-    from inspect import getargspec, formatargspec
-    from itertools import count
     class ValueFormatter(object):
         def __init__(self):
             self.count = count()
@@ -90,10 +91,8 @@ def execute_once(func):
     class ExecuteOnceFunctionWrapper(object):
         __slots__ = ('__weakref__', '__func__', '__callmap__', 'called', 'lock')
         def __init__(self, func):
-            from threading import RLock
-            from weakref import WeakKeyDictionary
             self.__func__ = func
-            self.__callmap__ = WeakKeyDictionary()
+            self.__callmap__ = weakobjectmap()
             self.__callmap__[func] = False
             self.lock = RLock()
         def __call__(self, *args, **kw):
