@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2007 Dan Pascu. See LICENSE for details.
+# Copyright (C) 2006-2012 Dan Pascu. See LICENSE for details.
 #
 
 """Event processing queues, that process the events in a distinct thread"""
@@ -9,11 +9,13 @@ import Queue
 from threading import Thread, Event, Lock
 
 from application import log
+from application.python.types import MarkerType
+
 
 # Special events that control the queue operation (for internal use)
-class StopProcessing: pass
-class ProcessEvents: pass
-class DiscardEvents: pass
+class StopProcessing: __metaclass__ = MarkerType
+class ProcessEvents:  __metaclass__ = MarkerType
+class DiscardEvents:  __metaclass__ = MarkerType
 
 
 class EventQueue(Thread):
@@ -42,7 +44,7 @@ class EventQueue(Thread):
                 break
             try:
                 self.handle(event)
-            except:
+            except Exception:
                 log.error("exception happened during event handling")
                 log.err()
             finally:
@@ -145,7 +147,7 @@ class CumulativeEventQueue(EventQueue):
                             raise ValueError("%s handler must return a list of unhandled events or None" % self.__class__.__name__)
                         if unhandled is not None:
                             preserved = unhandled ## preserve the unhandled events that the handler returned
-                    except:
+                    except Exception:
                         log.error("exception happened during event handling")
                         log.err()
                     self._waiting = preserved
@@ -155,7 +157,7 @@ class CumulativeEventQueue(EventQueue):
                 if getattr(event, 'high_priority', False):
                     try:
                         self.handle([event])
-                    except:
+                    except Exception:
                         log.error("exception happened during high priority event handling")
                         log.err()
                     finally:
